# Generated by Django 4.1.4 on 2022-12-13 18:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Classification',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('classificationid', models.BigIntegerField()),
                ('classificationname', models.CharField(blank=True, max_length=100, null=True)),
                ('level', models.IntegerField(blank=True, null=True)),
                ('parent', models.BigIntegerField(blank=True, null=True)),
                ('taxtypeid', models.IntegerField(blank=True, null=True)),
                ('groupid', models.IntegerField(blank=True, null=True)),
                ('tax', models.BooleanField(blank=True, null=True)),
                ('taxpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('taxcapitalized', models.BooleanField(blank=True, null=True)),
                ('depreciation', models.CharField(blank=True, max_length=2, null=True)),
                ('minimum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('maximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('lifespan', models.IntegerField(blank=True, null=True)),
                ('locationid', models.IntegerField(blank=True, null=True)),
                ('rent', models.IntegerField(blank=True, null=True)),
                ('businessid', models.IntegerField(blank=True, null=True)),
                ('impute', models.BooleanField(blank=True, null=True)),
                ('accountdevolution', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budget', models.BooleanField(blank=True, null=True)),
                ('budgetquantity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budgetvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('positiontariff', models.CharField(blank=True, max_length=20, null=True)),
                ('bonus', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bonus1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bonus2', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('prefix', models.CharField(blank=True, max_length=1, null=True)),
                ('inventory', models.CharField(blank=True, max_length=1, null=True)),
                ('blight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('blightcost', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('adjustmentcostvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('manpower', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('indirect', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('changeprice', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('expenseobjectid', models.IntegerField(blank=True, null=True)),
                ('costcenterid', models.IntegerField(blank=True, null=True)),
                ('oldcode', models.CharField(blank=True, max_length=20, null=True)),
                ('adjustmentcost', models.CharField(blank=True, max_length=1, null=True)),
                ('guarantee', models.IntegerField(blank=True, null=True)),
                ('guaranteevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('grouporder', models.IntegerField(blank=True, null=True)),
                ('typeasset', models.CharField(blank=True, max_length=2, null=True)),
                ('costmethod', models.CharField(blank=True, max_length=1, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('finite', models.BooleanField(blank=True, null=True)),
                ('depreciate', models.BooleanField(blank=True, null=True)),
                ('expiration', models.IntegerField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=1, null=True)),
                ('ambulatory', models.BooleanField(blank=True, null=True)),
                ('hospitable', models.BooleanField(blank=True, null=True)),
                ('mobile', models.BooleanField(blank=True, null=True)),
                ('domicile', models.BooleanField(blank=True, null=True)),
                ('other', models.BooleanField(blank=True, null=True)),
                ('gender', models.CharField(blank=True, max_length=1, null=True)),
                ('groupageid', models.IntegerField(blank=True, null=True)),
                ('cr', models.BooleanField(blank=True, null=True)),
                ('ir', models.BooleanField(blank=True, null=True)),
                ('low', models.BooleanField(blank=True, null=True)),
                ('medium', models.BooleanField(blank=True, null=True)),
                ('high', models.BooleanField(blank=True, null=True)),
                ('factor', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('recuperation', models.BooleanField(blank=True, null=True)),
                ('pyp', models.BooleanField(blank=True, null=True)),
                ('urgency', models.BooleanField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('flatratecost', models.BooleanField(blank=True, null=True)),
                ('judgment', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'classification',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Discount',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('discountid', models.IntegerField()),
                ('discountname', models.CharField(blank=True, max_length=100, null=True)),
                ('typediscountid', models.IntegerField(blank=True, null=True)),
                ('locationid', models.IntegerField(blank=True, null=True)),
                ('geographiclocationid', models.IntegerField(blank=True, null=True)),
                ('clientid', models.BigIntegerField(blank=True, null=True)),
                ('directionid', models.IntegerField(blank=True, null=True)),
                ('segmentid', models.IntegerField()),
                ('abcclient', models.CharField(max_length=1)),
                ('vendorid', models.BigIntegerField(blank=True, null=True)),
                ('dateinitial', models.DateTimeField(blank=True, null=True)),
                ('datefinal', models.DateTimeField(blank=True, null=True)),
                ('typeapplies', models.CharField(blank=True, max_length=1, null=True)),
                ('typepriceid', models.IntegerField(blank=True, null=True)),
                ('currencyid', models.IntegerField(blank=True, null=True)),
                ('exchangerate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('businessid', models.IntegerField(blank=True, null=True)),
                ('classificationid', models.IntegerField(blank=True, null=True)),
                ('productid', models.BigIntegerField(blank=True, null=True)),
                ('brandid', models.IntegerField(blank=True, null=True)),
                ('lineid', models.IntegerField(blank=True, null=True)),
                ('abcproduct', models.CharField(max_length=1)),
                ('price', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('discountpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('expirationinitial', models.DateField(blank=True, null=True)),
                ('expirationfinal', models.DateField(blank=True, null=True)),
                ('value', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bondpercentage', models.FloatField(blank=True, null=True)),
                ('bondvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('image', models.BinaryField(blank=True, null=True)),
                ('format', models.IntegerField(blank=True, null=True)),
                ('tariff', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('tariffsubstraction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('cost', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('typecampaign', models.CharField(blank=True, max_length=1, null=True)),
                ('state', models.CharField(blank=True, max_length=1, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('description', models.CharField(blank=True, max_length=4000, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('documentid', models.CharField(blank=True, max_length=3, null=True)),
                ('numberid', models.IntegerField(blank=True, null=True)),
                ('codeexternal', models.CharField(blank=True, max_length=10, null=True)),
            ],
            options={
                'db_table': 'discount',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('product_id', models.IntegerField(verbose_name='Product id')),
                ('name', models.CharField(max_length=250, verbose_name='Product name')),
                ('enabled', models.BooleanField(default=True, verbose_name='Is enabled')),
            ],
        ),
        migrations.CreateModel(
            name='OasisProduct',
            fields=[
                ('companyid', models.OneToOneField(db_column='companyid', on_delete=django.db.models.deletion.DO_NOTHING, primary_key=True, related_name='company_products', serialize=False, to='oasis.classification')),
                ('productid', models.BigIntegerField()),
                ('productname', models.CharField(blank=True, max_length=1000, null=True)),
                ('classificationid', models.IntegerField(blank=True, null=True)),
                ('service', models.BooleanField(blank=True, null=True)),
                ('inventory', models.CharField(blank=True, max_length=1, null=True)),
                ('price', models.CharField(blank=True, max_length=1, null=True)),
                ('individual', models.BooleanField(blank=True, null=True)),
                ('ingress', models.DateField(blank=True, null=True)),
                ('discount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('measureunitid', models.IntegerField(blank=True, null=True)),
                ('taxtypeid', models.IntegerField(blank=True, null=True)),
                ('groupid', models.IntegerField(blank=True, null=True)),
                ('tax', models.BooleanField(blank=True, null=True)),
                ('taxpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('unitalternate', models.IntegerField(blank=True, null=True)),
                ('factorconversion', models.FloatField(blank=True, null=True)),
                ('depreciation', models.CharField(blank=True, max_length=2, null=True)),
                ('lifespan', models.IntegerField(blank=True, null=True)),
                ('taxcapitalized', models.BooleanField(blank=True, null=True)),
                ('substitute', models.BigIntegerField(blank=True, null=True)),
                ('locationid', models.IntegerField(blank=True, null=True)),
                ('localizationid', models.CharField(blank=True, max_length=20, null=True)),
                ('clientid', models.BigIntegerField(blank=True, null=True)),
                ('oldcode', models.CharField(blank=True, max_length=100, null=True)),
                ('balance', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('inventoried', models.BooleanField(blank=True, null=True)),
                ('random', models.BigIntegerField(blank=True, null=True)),
                ('cycle', models.IntegerField(blank=True, null=True)),
                ('characteristic', models.BooleanField(blank=True, null=True)),
                ('characteristicid', models.IntegerField(blank=True, null=True)),
                ('presentation', models.BooleanField(blank=True, null=True)),
                ('presentationvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('expiration', models.BooleanField(blank=True, null=True)),
                ('control', models.BooleanField(blank=True, null=True)),
                ('lot', models.BooleanField(blank=True, null=True)),
                ('minimum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('standard', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('maximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('dynamic', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('costproduction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('averageactual', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('averageanterior', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('logo', models.IntegerField(blank=True, null=True)),
                ('level', models.IntegerField(blank=True, null=True)),
                ('abcnumber', models.IntegerField(blank=True, null=True)),
                ('production', models.BooleanField(blank=True, null=True)),
                ('state', models.CharField(blank=True, max_length=1, null=True)),
                ('rent', models.IntegerField(blank=True, null=True)),
                ('surtax', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('surtaxcapitalized', models.BooleanField(blank=True, null=True)),
                ('taxica', models.IntegerField(blank=True, null=True)),
                ('taxicap', models.IntegerField(blank=True, null=True)),
                ('taxdistributor', models.BooleanField(blank=True, null=True)),
                ('unitpurchase', models.IntegerField(blank=True, null=True)),
                ('unitsale', models.IntegerField(blank=True, null=True)),
                ('ean', models.BigIntegerField(blank=True, null=True)),
                ('generic', models.BooleanField(blank=True, null=True)),
                ('genericid', models.BigIntegerField(blank=True, null=True)),
                ('colorid', models.IntegerField(blank=True, null=True)),
                ('sizeid', models.IntegerField(blank=True, null=True)),
                ('genreid', models.IntegerField(blank=True, null=True)),
                ('materialid', models.IntegerField(blank=True, null=True)),
                ('gammaid', models.IntegerField(blank=True, null=True)),
                ('quality', models.BooleanField(blank=True, null=True)),
                ('origin', models.CharField(blank=True, max_length=1, null=True)),
                ('height', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('length', models.DecimalField(blank=True, db_column='long', decimal_places=4, max_digits=19, null=True)),
                ('width', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('volume', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('stock', models.BooleanField(blank=True, null=True)),
                ('budget', models.BooleanField(blank=True, null=True)),
                ('tolerancebudget', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budgetorder', models.BooleanField(blank=True, null=True)),
                ('planexportation', models.IntegerField(blank=True, null=True)),
                ('positiontariff', models.CharField(blank=True, max_length=20, null=True)),
                ('packing', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('box', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('businessid', models.IntegerField(blank=True, null=True)),
                ('combo', models.BooleanField(blank=True, null=True)),
                ('initials', models.CharField(blank=True, max_length=50, null=True)),
                ('daysdose', models.IntegerField(blank=True, null=True)),
                ('special', models.BooleanField(blank=True, null=True)),
                ('checked', models.BooleanField(blank=True, null=True)),
                ('pos', models.BooleanField(blank=True, null=True)),
                ('recovery', models.BooleanField(blank=True, null=True)),
                ('depth', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('designid', models.IntegerField(blank=True, null=True)),
                ('brandid', models.IntegerField(blank=True, null=True)),
                ('functionid', models.IntegerField(blank=True, null=True)),
                ('collectionid', models.IntegerField(blank=True, null=True)),
                ('codealternate', models.CharField(blank=True, max_length=20, null=True)),
                ('lineid', models.IntegerField(blank=True, null=True)),
                ('importation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('materialraw', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('materialrawind', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('manpower', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('manpowerind', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('direct', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('indirect', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('sex', models.CharField(blank=True, max_length=1, null=True)),
                ('ageinitial', models.IntegerField(blank=True, null=True)),
                ('agefinal', models.IntegerField(blank=True, null=True)),
                ('rangeage', models.CharField(blank=True, max_length=1, null=True)),
                ('levelattention', models.IntegerField(blank=True, null=True)),
                ('levelcomplexity', models.IntegerField(blank=True, null=True)),
                ('gruousurgical', models.IntegerField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=3, null=True)),
                ('quantity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quantitymaximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('elaborated', models.BigIntegerField(blank=True, null=True)),
                ('revised', models.BigIntegerField(blank=True, null=True)),
                ('approved', models.BigIntegerField(blank=True, null=True)),
                ('tokendate', models.DateField(blank=True, null=True)),
                ('producname1', models.CharField(blank=True, max_length=100, null=True)),
                ('productiondate', models.DateField(blank=True, null=True)),
                ('countryid', models.IntegerField(blank=True, null=True)),
                ('costdate', models.DateField(blank=True, null=True)),
                ('costproductiondate', models.DateField(blank=True, null=True)),
                ('lastpurchase', models.DateField(blank=True, null=True)),
                ('lastsupplier', models.BigIntegerField(blank=True, null=True)),
                ('lastprice', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('coststandard', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('activityica', models.IntegerField(blank=True, null=True)),
                ('eanchar', models.CharField(blank=True, max_length=30, null=True)),
                ('tariffhealth', models.IntegerField(blank=True, null=True)),
                ('finance', models.BooleanField(blank=True, null=True)),
                ('abc', models.CharField(blank=True, max_length=1, null=True)),
                ('capacity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('localization2', models.CharField(blank=True, max_length=20, null=True)),
                ('descriptiontariff', models.CharField(blank=True, max_length=50, null=True)),
                ('margin', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('additionalprice1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('additionalprice2', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('taxvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('marginminimum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('marginmaximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('fund', models.IntegerField(blank=True, null=True)),
                ('factor', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('sourceid', models.IntegerField(blank=True, null=True)),
                ('entryid', models.BigIntegerField(blank=True, null=True)),
                ('expenseobjectid', models.IntegerField(blank=True, null=True)),
                ('returnable', models.BooleanField(blank=True, null=True)),
                ('growth', models.IntegerField(blank=True, null=True)),
                ('marked', models.BooleanField(blank=True, null=True)),
                ('invimadate', models.DateField(blank=True, null=True)),
                ('bpmdate', models.DateField(blank=True, null=True)),
                ('namegeneric', models.CharField(blank=True, max_length=100, null=True)),
                ('namecommercial', models.CharField(blank=True, max_length=100, null=True)),
                ('field1', models.CharField(blank=True, max_length=10, null=True)),
                ('field2', models.CharField(blank=True, max_length=10, null=True)),
                ('field3', models.CharField(blank=True, max_length=10, null=True)),
                ('emission', models.DateField(blank=True, null=True)),
                ('expirationdate', models.DateField(blank=True, null=True)),
                ('interestrate', models.DateField(blank=True, null=True)),
                ('periodicity', models.CharField(blank=True, max_length=2, null=True)),
                ('lastcoupondate', models.DateField(blank=True, null=True)),
                ('currencyid', models.IntegerField(blank=True, null=True)),
                ('performance', models.CharField(blank=True, max_length=1, null=True)),
                ('consignment', models.BooleanField(blank=True, null=True)),
                ('serial', models.BooleanField(blank=True, null=True)),
                ('requireean128', models.BooleanField(blank=True, null=True)),
                ('ean128', models.CharField(blank=True, max_length=128, null=True)),
                ('costcenterid', models.IntegerField(blank=True, null=True)),
                ('projectid', models.IntegerField(blank=True, null=True)),
                ('costcenterid1', models.IntegerField(blank=True, null=True)),
                ('seal', models.IntegerField(blank=True, null=True)),
                ('bonus', models.BooleanField(blank=True, null=True)),
                ('image', models.BinaryField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('valuenominal', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('class_field', models.CharField(blank=True, db_column='class', max_length=1, null=True)),
                ('codeinvima', models.CharField(blank=True, max_length=20, null=True)),
                ('partial', models.BooleanField(blank=True, null=True)),
                ('groupsurgicalid', models.IntegerField(blank=True, null=True)),
                ('copayment', models.BooleanField(blank=True, null=True)),
                ('parturition', models.BooleanField(blank=True, null=True)),
                ('highcost', models.IntegerField(blank=True, null=True)),
                ('upc', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('grouppharmacologicalid', models.IntegerField(blank=True, null=True)),
                ('principleactiveid', models.IntegerField(blank=True, null=True)),
                ('formpharmaceuticalid', models.IntegerField(blank=True, null=True)),
                ('concentrationid', models.IntegerField(blank=True, null=True)),
                ('homologous', models.BooleanField(blank=True, null=True)),
                ('concentration', models.CharField(blank=True, max_length=100, null=True)),
                ('codehomologous', models.CharField(blank=True, max_length=100, null=True)),
                ('cups', models.BooleanField(blank=True, null=True)),
                ('levelauthorization', models.IntegerField(blank=True, null=True)),
                ('classificationidalternate', models.BigIntegerField(blank=True, null=True)),
                ('automatic', models.BooleanField(blank=True, null=True)),
                ('quantitytime', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('nounification', models.BooleanField(blank=True, null=True)),
                ('quantitymonth', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quantityyear', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('valueminimum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('valuemaximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quotamoderator', models.BooleanField(blank=True, null=True)),
                ('highcostcontrib', models.IntegerField(blank=True, null=True)),
                ('capitated', models.BooleanField(blank=True, null=True)),
                ('print', models.BooleanField(blank=True, null=True)),
                ('atcpos', models.CharField(blank=True, max_length=20, null=True)),
                ('typegeneric', models.CharField(blank=True, max_length=20, null=True)),
                ('health', models.BooleanField(blank=True, null=True)),
                ('description', models.CharField(blank=True, max_length=4000, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('codeium', models.CharField(blank=True, max_length=30, null=True)),
                ('codeium1', models.CharField(blank=True, max_length=30, null=True)),
                ('codeium2', models.CharField(blank=True, max_length=30, null=True)),
                ('coldchain', models.BooleanField(blank=True, null=True)),
                ('regulated', models.BooleanField(blank=True, null=True)),
                ('valuerecovery', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('temperature', models.BooleanField(blank=True, null=True)),
                ('judgment', models.IntegerField(blank=True, null=True)),
                ('diagnostic', models.IntegerField(blank=True, null=True)),
                ('retentionbyproduct', models.BooleanField(blank=True, null=True)),
                ('coffeefreight', models.CharField(blank=True, max_length=1, null=True)),
                ('combomodel', models.CharField(blank=True, max_length=1, null=True)),
                ('productcurve', models.BooleanField(blank=True, null=True)),
                ('coverid', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'product',
                'managed': False,
            },
        ),
        migrations.AddConstraint(
            model_name='product',
            constraint=models.UniqueConstraint(fields=('product_id',), name='ownproduct_productid_unique'),
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-07 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0016_statemachine_is_changed_statemachine_timeout'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='state_at_timeout',
            field=models.IntegerField(blank=True, choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], null=True, verbose_name='State at timeout'),
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         6/03/23 16:34
# Project:      CFHL Transactional Backend
# Module Name:  sync_coffe_offers
# Description:
# ****************************************************************
from core import celery_app
from django.conf import settings
from oasis.coffee_offers.lib.utils import OfferStateMachine
from oasis.models import Offer
from oasis.models import Operation
from typing import Any


@celery_app.task(bind=True)
def sync_coffee_offers(app: Any):
    document_id = settings.COFFEE_OFFERS_DOCUMENT

    offer_qs = Offer.objects.get_all_active_offers()
    for offer in offer_qs:
        operation = Operation.objects.get_by_operation_pk(document_id=document_id,
                                                          location_id=offer.warehouse.location_id,
                                                          number_id=offer.contract).first()
        if operation is not None:
            state_machine = OfferStateMachine(offer, operation)
            state_machine.run()
            state_machine.validate_timeout()



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         3/03/23 16:25
# Project:      CFHL Transactional Backend
# Module Name:  oasis_operation
# Description:
# ****************************************************************
import cx_Oracle
from datetime import datetime
from django.conf import settings
from django.db import connections
from django.db import DatabaseError
from django.utils.translation import gettext_lazy as _
from oasis import models as oasis_models

from typing import Any
from zibanu.django.db import models


class Operation(models.Manager):
    connection_name = "oasis"

    def __get_cursor(self):
        return connections[self.connection_name].cursor()

    def __get_connection(self):
        return connections[self.connection_name]

    def get_by_operation_pk(self, document_id: str, location_id: int, number_id: int) -> models.QuerySet:
        """
        Return an operation with oasis pk filter
        :param document_id: Document id
        :param location_id: Location id
        :param number_id: Document number id
        :return: Queryset
        """
        return self.filter(companyid__exact=settings.OASIS_DEFAULT_COMPANY, locationid__exact=location_id,
                           numberid__exact=number_id, documentid__startswith=document_id)

    def operation_insert(self, user: Any, product_id: int, location_id: int, amount: float, price: float, to_date: str):
        """
        Method to insert an operation record in OASIS4
        :param user:
        :param product_id:
        :param location_id:
        :param amount:
        :param price:
        :param to_date:
        :return:
        """
        # Set Queries
        operation_insert = "p_operationinsert"
        operation_insert_detail = "p_operationinsertdetail"
        # Update operation table after insertion
        update_operation = "update oasis4.operation set motiveid = :motive_id, otherif = :amount, " \
                           "initialdate = :initial_date, finaldate = :final_date, status='P' " \
                           "where companyid = :company_id and locationid = :location_id " \
                           "and numberid = :number_id and trim(documentid) = :document_id"
        # Update discount table after insertion
        update_discount = "update oasis4.discount set productid = :product_id, price= :price, " \
                          "dateinitial = :initial_date, datefinal = :final_date " \
                          "where companyid = :company_id and locationid = :location_id " \
                          "and numberid = :number_id and trim(documentid) = :document_id " \
                          "and typediscountid = :type_discount_id"
        try:
            company_id = settings.OASIS_DEFAULT_COMPANY
            contact_id = settings.OASIS_DEFAULT_COMPANY_ID
            date_now = datetime.now()
            to_date = datetime.strptime(to_date, "%Y-%m-%d")
            client_id = user.profile.document_id
            document_id = settings.COFFEE_OFFERS_DOCUMENT
            concept_id = settings.COFFEE_OFFERS_CONCEPT
            motive_id = settings.COFFEE_OFFERS_MOTIVE
            product = oasis_models.Product.objects.get(pk=product_id)

            cursor = self.__get_cursor()
            operation_number = cursor.var(cx_Oracle.NUMBER).var
            # Call operation insert procedure
            cursor.callproc(operation_insert, [
                company_id,
                document_id,
                location_id,
                concept_id,
                0,
                date_now,
                client_id,
                contact_id,
                operation_number
            ])

            if operation_number:
                # Update motive and quantity on operation table.
                number_id = operation_number.getvalue()
                cursor.execute(update_operation, {
                    "motive_id": motive_id,
                    "amount": amount,
                    "company_id": company_id,
                    "location_id": location_id,
                    "number_id": number_id,
                    "document_id": document_id,
                    "initial_date": date_now,
                    "final_date": to_date
                })
                if cursor.rowcount > 0:
                    # Execute operation_insert_detail procedure
                    cursor.callproc(operation_insert_detail, [
                        company_id,
                        document_id,
                        number_id,
                        location_id
                    ])
                    # Update product and price on discount.
                    cursor.execute(update_discount, {
                        "product_id": product.product_id,
                        "price": price,
                        "company_id": company_id,
                        "location_id": location_id,
                        "number_id": number_id,
                        "document_id": document_id,
                        "type_discount_id": settings.COFFEE_OFFERS_DISCOUNT,
                        "initial_date": date_now,
                        "final_date": to_date
                    })

                    if cursor.rowcount > 0:
                        warehouse = oasis_models.CoffeeWareHouse.objects.filter(location_id__exact=location_id).get()
                        offer = oasis_models.Offer(product=product, contract=number_id, kg_offered=amount,
                                                   delivery_date=to_date, user=user, warehouse=warehouse, price=price)
                        offer.save(force_insert=True)
                        b_return = True
                    else:
                        raise DatabaseError(_("Error updating OASIS4 database."))
                else:
                    raise DatabaseError(_("Error updating OASIS4 database."))
            else:
                raise DatabaseError(_("Error inserting OASIS4 database."))
        except Exception:
            raise
        else:
            return b_return

    def update_status(self, location_id: int, number_id: int, document_id: str, state: str, status: str) -> bool:
        company_id = settings.OASIS_DEFAULT_COMPANY
        update_operation = "update oasis4.operation set state = :state, status = :status " \
                           "where companyid = :company_id and locationid = :location_id " \
                           "and numberid = :number_id and documentid = :document_id"

        cursor = self.__get_cursor()
        cursor.execute(update_operation, {
            "state": state,
            "status": status,
            "company_id": company_id,
            "location_id": location_id,
            "number_id": number_id,
            "document_id": document_id
        })

        return cursor.rowcount == 1




# Generated by Django 4.1.7 on 2023-03-06 20:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0012_offer_price'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='is_final',
            field=models.BooleanField(default=False, verbose_name='Is final state'),
        ),
        migrations.AddField(
            model_name='statemachine',
            name='is_initial',
            field=models.BooleanField(default=False, verbose_name='Is initial state'),
        ),
        migrations.AlterField(
            model_name='offer',
            name='status',
            field=models.IntegerField(choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], default=0, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='offer',
            name='warehouse',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_query_name='warehouse', to='oasis.coffeewarehouse', verbose_name='Warehouse'),
        ),
        migrations.AlterField(
            model_name='statemachine',
            name='from_state',
            field=models.IntegerField(blank=True, choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], null=True, verbose_name='From State'),
        ),
        migrations.AlterField(
            model_name='statemachine',
            name='state',
            field=models.IntegerField(choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], default=0, verbose_name='State'),
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-07 08:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0014_remove_statemachine_unq_coffeeoffer_statemachine_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='update_oasis',
            field=models.BooleanField(default=False, verbose_name='Update Oasis'),
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         23/02/23 9:16
# Project:      CFHL Transactional Backend
# Module Name:  oasis_location
# Description:
# ****************************************************************
from zibanu.django.db import models


class OasisLocation(models.Manager):
    """
    Manager class of Location class entity
    """
    def get_coffe_ware_houses(self):
        qs = self.get_queryset().filter(businessid__exact=1, level__exact=2, pointofsales__exact=1)
        return qs





# Generated by Django 4.1.7 on 2023-03-16 21:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0017_statemachine_state_at_timeout'),
    ]

    operations = [
        migrations.CreateModel(
            name='OfferMov',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('modified_at', models.DateTimeField(auto_now=True, verbose_name='Modified at')),
                ('status', models.IntegerField(choices=[(0, 'New'), (1, 'Changed'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')])),
                ('delivery_date', models.DateField(blank=True, null=True)),
                ('price', models.DecimalField(blank=True, decimal_places=2, max_digits=7, null=True)),
                ('kg_offered', models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True)),
                ('kg_received', models.DecimalField(blank=True, decimal_places=2, max_digits=9, null=True)),
                ('created', models.BooleanField(default=False)),
                ('offer', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='offer_movements', related_query_name='offer', to='oasis.offer')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         23/02/23 9:38
# Project:      CFHL Transactional Backend
# Module Name:  local_coffee_ware_house
# Description:
# ****************************************************************
from zibanu.django.db import models


class CoffeeWareHouse(models.Manager):
    """
    Manager class for CoffeeWarehouse entity
    """
    def get_by_location_id(self, location_id: int):
        return self.get_queryset().filter(location_id__exact=location_id)


# Generated by Django 4.1.7 on 2023-03-07 08:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0013_statemachine_is_final_statemachine_is_initial_and_more'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='statemachine',
            name='UNQ_CoffeeOffer_StateMachine',
        ),
        migrations.AddField(
            model_name='statemachine',
            name='send_contract',
            field=models.BooleanField(default=False, verbose_name='Send contract'),
        ),
        migrations.AddConstraint(
            model_name='statemachine',
            constraint=models.UniqueConstraint(fields=('state', 'from_state', 'oasis_state', 'oasis_status'), name='UNQ_CoffeeOffer_StateMachine'),
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         26/02/23 15:25
# Project:      CFHL Transactional Backend
# Module Name:  __init__.py
# Description:
# ****************************************************************



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         24/01/23 5:55 PM
# Project:      CFHL Transactional Backend
# Module Name:  sync_company
# Description:
# ****************************************************************
from core import celery_app
from oasis import models
from typing import Any


@celery_app.task(bind=True)
def sync_company(app: Any):
    oasis_qs = models.OasisCompany.objects.get_for_sync()
    if oasis_qs.count() > 0:
        # Get dataDict
        oasis_company = oasis_qs.first()
        # Validate if company exists
        company_qs = models.Company.objects.filter(company_id__exact=oasis_company.get("companyid"))
        if company_qs.count() == 0:
            company = models.Company(company_id=oasis_company.get("companyid"))
        else:
            company = company_qs.first()

        company.name = oasis_company.get("companyname")
        company.legal_representative = oasis_company.get("representative")
        company.tax_id = oasis_company.get("companycode")
        company.address = oasis_company.get("address")
        company.phone = oasis_company.get("phone")
        company.city = oasis_company.get("city")
        company.save()






# Generated by Django 4.1.5 on 2023-01-17 22:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='GeographicLocation',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('geographiclocationid', models.IntegerField()),
                ('geographiclocationname', models.CharField(blank=True, max_length=100, null=True)),
                ('parent', models.IntegerField(blank=True, null=True)),
                ('locationid', models.IntegerField(blank=True, null=True)),
                ('population', models.IntegerField(blank=True, null=True)),
                ('countryid', models.IntegerField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=1, null=True)),
                ('exempt', models.BooleanField(blank=True, null=True)),
                ('alternatecode', models.IntegerField(blank=True, null=True)),
                ('groupid', models.IntegerField(blank=True, null=True)),
                ('iatacode', models.CharField(blank=True, max_length=3, null=True)),
                ('clientid', models.BigIntegerField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('typeupc', models.CharField(blank=True, max_length=30, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('phonecode', models.CharField(blank=True, max_length=10, null=True)),
                ('latitude', models.CharField(blank=True, max_length=30, null=True)),
                ('longitude', models.CharField(blank=True, max_length=30, null=True)),
            ],
            options={
                'db_table': 'geographiclocation',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='TypeClient',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('typeclientid', models.CharField(max_length=1)),
                ('typeclientname', models.CharField(blank=True, max_length=100, null=True)),
                ('taxentity', models.IntegerField(blank=True, null=True)),
                ('typedocumentid', models.CharField(blank=True, max_length=2, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('typeclient', models.CharField(blank=True, max_length=1, null=True)),
                ('typeexternal', models.CharField(blank=True, max_length=10, null=True)),
                ('typeclient1', models.CharField(blank=True, max_length=1, null=True)),
            ],
            options={
                'db_table': 'typeclient',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='DocumentType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type_id', models.CharField(max_length=1, verbose_name='Document type oasis id')),
                ('description', models.CharField(max_length=50, verbose_name='Document type description')),
            ],
        ),
        migrations.CreateModel(
            name='Client',
            fields=[
                ('companyid', models.OneToOneField(db_column='companyid', on_delete=django.db.models.deletion.DO_NOTHING, primary_key=True, related_name='clients', serialize=False, to='oasis.geographiclocation')),
                ('clientid', models.BigIntegerField()),
                ('clientname', models.CharField(blank=True, max_length=100, null=True)),
                ('clienttype', models.CharField(blank=True, max_length=1, null=True)),
                ('clientcode', models.CharField(blank=True, max_length=20, null=True)),
                ('national', models.BooleanField(blank=True, null=True)),
                ('representative', models.CharField(blank=True, max_length=100, null=True)),
                ('address', models.CharField(blank=True, max_length=100, null=True)),
                ('phone', models.CharField(blank=True, max_length=30, null=True)),
                ('celphone', models.CharField(blank=True, max_length=30, null=True)),
                ('fax', models.CharField(blank=True, max_length=30, null=True)),
                ('zipcode', models.CharField(blank=True, max_length=20, null=True)),
                ('email', models.CharField(blank=True, max_length=200, null=True)),
                ('geographiclocationid', models.IntegerField(blank=True, db_column='geographiclocationid', null=True)),
                ('checkdigit', models.IntegerField(blank=True, null=True)),
                ('groupid', models.IntegerField(blank=True, null=True)),
                ('vendorid', models.BigIntegerField(blank=True, null=True)),
                ('locationid', models.IntegerField(blank=True, null=True)),
                ('discount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('conditionpaymentid', models.IntegerField(blank=True, null=True)),
                ('pricetypeid', models.IntegerField(blank=True, null=True)),
                ('tax', models.BooleanField(blank=True, null=True)),
                ('client_class', models.CharField(blank=True, db_column='class', max_length=1, null=True)),
                ('segmentid', models.IntegerField(blank=True, null=True)),
                ('remissioninvoice', models.CharField(blank=True, max_length=1, null=True)),
                ('deliverybill', models.CharField(blank=True, max_length=1, null=True)),
                ('deliverybilldirectionid', models.IntegerField(blank=True, null=True)),
                ('deliverystatement', models.CharField(blank=True, max_length=1, null=True)),
                ('deliverystatementdirectionid', models.IntegerField(blank=True, null=True)),
                ('customer', models.BooleanField(blank=True, null=True)),
                ('taxtypeid', models.IntegerField(blank=True, null=True)),
                ('userid', models.IntegerField(blank=True, null=True)),
                ('alternatecode', models.CharField(blank=True, max_length=15, null=True)),
                ('matrixid', models.BigIntegerField(blank=True, null=True)),
                ('limit', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('lastpurchase', models.DateField(blank=True, null=True)),
                ('specialityid', models.IntegerField(blank=True, null=True)),
                ('programid', models.IntegerField(blank=True, null=True)),
                ('purchasepaymentconditionid', models.IntegerField(blank=True, null=True)),
                ('purchasediscount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('taxprice', models.CharField(blank=True, max_length=1, null=True)),
                ('supplier', models.BooleanField(blank=True, null=True)),
                ('salescontact', models.CharField(blank=True, max_length=100, null=True)),
                ('paymentcontact', models.CharField(blank=True, max_length=100, null=True)),
                ('purchasecontact', models.CharField(blank=True, max_length=100, null=True)),
                ('entrydate', models.DateField(blank=True, null=True)),
                ('retirementdate', models.DateField(blank=True, null=True)),
                ('paymentformid', models.IntegerField(blank=True, null=True)),
                ('area', models.CharField(blank=True, max_length=1, null=True)),
                ('bankaccount', models.CharField(blank=True, max_length=20, null=True)),
                ('socialinsurance', models.CharField(blank=True, max_length=20, null=True)),
                ('medicalinsurance', models.CharField(blank=True, max_length=20, null=True)),
                ('turnid', models.IntegerField(blank=True, null=True)),
                ('employee', models.BooleanField(blank=True, null=True)),
                ('vendor', models.BooleanField(blank=True, null=True)),
                ('shareholder', models.BooleanField(blank=True, null=True)),
                ('partner', models.BooleanField(blank=True, null=True)),
                ('state', models.CharField(blank=True, max_length=1, null=True)),
                ('industrialactivity', models.IntegerField(blank=True, null=True)),
                ('industrialtax', models.BooleanField(blank=True, null=True)),
                ('retention', models.BooleanField(blank=True, null=True)),
                ('deductibleretention', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('birthdate', models.DateField(blank=True, null=True)),
                ('birthlocationid', models.IntegerField(blank=True, null=True)),
                ('civilstatus', models.CharField(blank=True, max_length=1, null=True)),
                ('education', models.CharField(blank=True, max_length=1, null=True)),
                ('professionid', models.IntegerField(blank=True, null=True)),
                ('currentcompany', models.CharField(blank=True, max_length=40, null=True)),
                ('currentcompanycode', models.CharField(blank=True, max_length=20, null=True)),
                ('ingress', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('entrycompanydate', models.DateField(blank=True, null=True)),
                ('house', models.CharField(blank=True, max_length=1, null=True)),
                ('housevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('car', models.CharField(blank=True, max_length=1, null=True)),
                ('carvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('spouse', models.CharField(blank=True, max_length=100, null=True)),
                ('spousecode', models.CharField(blank=True, max_length=20, null=True)),
                ('child', models.IntegerField(blank=True, null=True)),
                ('distributortax', models.CharField(blank=True, max_length=1, null=True)),
                ('firstlastname', models.CharField(blank=True, max_length=20, null=True)),
                ('secondlastname', models.CharField(blank=True, max_length=30, null=True)),
                ('firstfirstname', models.CharField(blank=True, max_length=20, null=True)),
                ('secondfirstname', models.CharField(blank=True, max_length=30, null=True)),
                ('sex', models.CharField(blank=True, max_length=1, null=True)),
                ('additionalupc', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('specialrate', models.DecimalField(blank=True, decimal_places=4, max_digits=6, null=True)),
                ('beneficiaryid', models.BigIntegerField(blank=True, null=True)),
                ('bankid', models.IntegerField(blank=True, null=True)),
                ('governmental', models.BooleanField(blank=True, null=True)),
                ('abbreviation', models.CharField(blank=True, max_length=60, null=True)),
                ('bankaccounttype', models.CharField(blank=True, max_length=1, null=True)),
                ('delaytolerance', models.IntegerField(blank=True, null=True)),
                ('partialdispatch', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('partialdispatchproduct', models.BooleanField(blank=True, null=True)),
                ('separation', models.CharField(blank=True, max_length=1, null=True)),
                ('billing', models.CharField(blank=True, max_length=1, null=True)),
                ('currencyid', models.IntegerField(blank=True, null=True)),
                ('languageid', models.IntegerField(blank=True, null=True)),
                ('zoneid', models.IntegerField(blank=True, null=True)),
                ('tagid', models.IntegerField(blank=True, null=True)),
                ('incoterms', models.CharField(blank=True, max_length=3, null=True)),
                ('abc', models.CharField(blank=True, max_length=1, null=True)),
                ('quotacollection', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quotatype', models.CharField(blank=True, max_length=1, null=True)),
                ('bond', models.CharField(blank=True, max_length=1, null=True)),
                ('quotavalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('qualification', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('collectorid', models.BigIntegerField(blank=True, null=True)),
                ('authorizedid', models.BigIntegerField(blank=True, null=True)),
                ('conditiondirection', models.BooleanField(blank=True, null=True)),
                ('channelid', models.IntegerField(blank=True, null=True)),
                ('supervisorid', models.IntegerField(blank=True, null=True)),
                ('priority', models.IntegerField(blank=True, null=True)),
                ('promptpaymentid', models.IntegerField(blank=True, null=True)),
                ('rotation', models.IntegerField(blank=True, null=True)),
                ('dispatchminimun', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('plan', models.IntegerField(blank=True, null=True)),
                ('creditdata', models.CharField(blank=True, max_length=1, null=True)),
                ('declarant', models.BooleanField(blank=True, null=True)),
                ('replication', models.CharField(blank=True, max_length=30, null=True)),
                ('beneficiary', models.BooleanField(blank=True, null=True)),
                ('contracttype', models.CharField(blank=True, max_length=1, null=True)),
                ('contractdate', models.DateField(blank=True, null=True)),
                ('frequent', models.BooleanField(blank=True, null=True)),
                ('educationaldegree', models.CharField(blank=True, max_length=2, null=True)),
                ('occupation', models.CharField(blank=True, max_length=1, null=True)),
                ('occupied', models.CharField(blank=True, max_length=1, null=True)),
                ('occupiedcode', models.IntegerField(blank=True, null=True)),
                ('lastdate', models.DateField(blank=True, null=True)),
                ('lastproduct', models.IntegerField(blank=True, null=True)),
                ('lastlocation', models.IntegerField(blank=True, null=True)),
                ('healthfee', models.IntegerField(blank=True, null=True)),
                ('affiliate', models.BooleanField(blank=True, null=True)),
                ('neighborhoodid', models.IntegerField(blank=True, null=True)),
                ('oldentity', models.CharField(blank=True, max_length=12, null=True)),
                ('asuranceaffiliationdate', models.DateField(blank=True, null=True)),
                ('disability', models.CharField(blank=True, max_length=1, null=True)),
                ('ethnicgroup', models.CharField(blank=True, max_length=2, null=True)),
                ('totalpoints', models.IntegerField(blank=True, null=True)),
                ('family', models.CharField(blank=True, max_length=1, null=True)),
                ('sisbenfile', models.IntegerField(blank=True, null=True)),
                ('sisbennucleus', models.IntegerField(blank=True, null=True)),
                ('sisbennumber', models.IntegerField(blank=True, null=True)),
                ('sisbendate', models.DateField(blank=True, null=True)),
                ('sisbenlevel', models.IntegerField(blank=True, null=True)),
                ('sisbenpoints', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('affiliatetype', models.CharField(blank=True, max_length=1, null=True)),
                ('matrixclienttype', models.CharField(blank=True, max_length=1, null=True)),
                ('populationgroup', models.CharField(blank=True, max_length=2, null=True)),
                ('affiliatestatus', models.CharField(blank=True, max_length=1, null=True)),
                ('locality', models.CharField(blank=True, max_length=40, null=True)),
                ('zone', models.CharField(blank=True, max_length=1, null=True)),
                ('highcost', models.BooleanField(blank=True, null=True)),
                ('authorizationlevel', models.IntegerField(blank=True, null=True)),
                ('credit', models.BooleanField(blank=True, null=True)),
                ('documentlocationid', models.IntegerField(blank=True, null=True)),
                ('retentionvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('food', models.CharField(blank=True, max_length=2, null=True)),
                ('foodprime', models.CharField(blank=True, max_length=1, null=True)),
                ('foodprimeextra', models.CharField(blank=True, max_length=1, null=True)),
                ('clock', models.BooleanField(blank=True, null=True)),
                ('employeestate', models.CharField(blank=True, max_length=1, null=True)),
                ('positionid', models.IntegerField(blank=True, null=True)),
                ('height', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('rh', models.CharField(blank=True, max_length=3, null=True)),
                ('laborlocationid', models.IntegerField(blank=True, null=True)),
                ('time', models.IntegerField(blank=True, null=True)),
                ('paymentlocationid', models.IntegerField(blank=True, null=True)),
                ('expeditiondocumentdate', models.DateField(blank=True, null=True)),
                ('expirationdocumentdate', models.DateField(blank=True, null=True)),
                ('expirationdocument', models.CharField(blank=True, max_length=10, null=True)),
                ('expirationentity', models.CharField(blank=True, max_length=1, null=True)),
                ('duplicateentity', models.CharField(blank=True, max_length=10, null=True)),
                ('motive', models.CharField(blank=True, max_length=3, null=True)),
                ('revised', models.DateField(blank=True, null=True)),
                ('idunumber', models.CharField(blank=True, max_length=15, null=True)),
                ('land', models.CharField(blank=True, max_length=60, null=True)),
                ('farm', models.CharField(blank=True, max_length=60, null=True)),
                ('ciiuid', models.IntegerField(blank=True, null=True)),
                ('replydays', models.IntegerField(blank=True, null=True)),
                ('voucherinitial', models.DateField(blank=True, null=True)),
                ('voucherfinal', models.DateField(blank=True, null=True)),
                ('vouchercomply', models.CharField(blank=True, max_length=1, null=True)),
                ('fiscaldocument', models.CharField(blank=True, max_length=3, null=True)),
                ('image', models.BinaryField(blank=True, null=True)),
                ('individual', models.CharField(blank=True, max_length=1, null=True)),
                ('paymentdays', models.IntegerField(blank=True, null=True)),
                ('birthday', models.DateField(blank=True, null=True)),
                ('marked', models.BooleanField(blank=True, null=True)),
                ('voucher', models.CharField(blank=True, max_length=3, null=True)),
                ('costcenterid', models.IntegerField(blank=True, null=True)),
                ('coffeelimit', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('coffeelimitused', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('signature', models.BinaryField(blank=True, null=True)),
                ('partnerstate', models.CharField(blank=True, max_length=1, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('typedocumentid', models.CharField(blank=True, max_length=2, null=True)),
                ('headid', models.BigIntegerField(blank=True, null=True)),
                ('kinshipid', models.IntegerField(blank=True, null=True)),
                ('grouppopulationid', models.IntegerField(blank=True, null=True)),
                ('condition', models.CharField(blank=True, max_length=1, null=True)),
                ('affiliation', models.DateField(blank=True, null=True)),
                ('consecutive', models.CharField(blank=True, max_length=20, null=True)),
                ('stateaffiliate', models.CharField(blank=True, max_length=2, null=True)),
                ('activationdate', models.DateField(blank=True, null=True)),
                ('suspensiondate', models.DateField(blank=True, null=True)),
                ('report', models.CharField(blank=True, max_length=2, null=True)),
                ('neighborhood', models.CharField(blank=True, max_length=30, null=True)),
                ('datereport', models.DateField(blank=True, null=True)),
                ('translation', models.CharField(blank=True, max_length=2, null=True)),
                ('epsidanterior', models.IntegerField(blank=True, null=True)),
                ('epsidcross', models.IntegerField(blank=True, null=True)),
                ('ingressvalidity', models.CharField(blank=True, max_length=1, null=True)),
                ('registerduria', models.CharField(blank=True, max_length=10, null=True)),
                ('epsidscross', models.IntegerField(blank=True, null=True)),
                ('locationidcross', models.IntegerField(blank=True, null=True)),
                ('resolution', models.CharField(blank=True, max_length=20, null=True)),
                ('core', models.CharField(blank=True, max_length=1, null=True)),
                ('home', models.CharField(blank=True, max_length=2, null=True)),
                ('bdua', models.CharField(blank=True, max_length=2, null=True)),
                ('locationidcross1', models.IntegerField(blank=True, null=True)),
                ('datepoll', models.DateField(blank=True, null=True)),
                ('datechangestate', models.DateField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=1, null=True)),
                ('gloss', models.CharField(blank=True, max_length=10, null=True)),
                ('statecross', models.CharField(blank=True, max_length=2, null=True)),
                ('groupinadequate', models.BooleanField(blank=True, null=True)),
                ('cellular', models.CharField(blank=True, max_length=20, null=True)),
                ('cellular2', models.CharField(blank=True, max_length=20, null=True)),
                ('charingress', models.CharField(blank=True, max_length=1, null=True)),
                ('evolution', models.IntegerField(blank=True, null=True)),
                ('numberbirth', models.IntegerField(blank=True, null=True)),
                ('coverdate', models.DateField(blank=True, null=True)),
                ('validatebdua', models.BooleanField(blank=True, null=True)),
                ('glossbdua', models.CharField(blank=True, max_length=400, null=True)),
                ('statebdua', models.CharField(blank=True, max_length=2, null=True)),
                ('criterionvalidate', models.IntegerField(blank=True, null=True)),
                ('biometria', models.BooleanField(blank=True, null=True)),
                ('groupageid', models.IntegerField(blank=True, null=True)),
                ('upc', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('portability', models.BooleanField(blank=True, null=True)),
                ('regimen', models.CharField(blank=True, max_length=1, null=True)),
                ('levelemployery', models.IntegerField(blank=True, null=True)),
                ('typeemployery', models.IntegerField(blank=True, null=True)),
                ('sisbenmethodology', models.IntegerField(blank=True, null=True)),
                ('alfanet', models.BigIntegerField(blank=True, null=True)),
                ('geographiclocationidactual', models.IntegerField(blank=True, null=True)),
                ('multiaffiliatecross', models.CharField(blank=True, max_length=1, null=True)),
                ('kinshipemployery', models.CharField(blank=True, max_length=2, null=True)),
                ('actuaphone', models.BooleanField(blank=True, null=True)),
                ('actuaaddress', models.BooleanField(blank=True, null=True)),
                ('statetenebit', models.CharField(blank=True, max_length=1, null=True)),
                ('fum', models.DateField(blank=True, null=True)),
                ('pertaintenebit', models.BooleanField(blank=True, null=True)),
                ('numberidinform', models.IntegerField(blank=True, null=True)),
                ('clientidant', models.BigIntegerField(blank=True, null=True)),
                ('upcadditional', models.BooleanField(blank=True, null=True)),
                ('initiationupcadditional', models.DateField(blank=True, null=True)),
                ('employerid', models.BigIntegerField(blank=True, null=True)),
                ('formpaymentid', models.IntegerField(blank=True, null=True)),
                ('scene', models.IntegerField(blank=True, null=True)),
                ('locationaccessid', models.IntegerField(blank=True, null=True)),
                ('compromisetext', models.CharField(blank=True, max_length=4000, null=True)),
                ('dispatchtext', models.CharField(blank=True, max_length=4000, null=True)),
                ('processbiometric', models.IntegerField(blank=True, null=True)),
                ('fingerright', models.IntegerField(blank=True, null=True)),
                ('fingerprintr1', models.BinaryField(blank=True, null=True)),
                ('fingerprintr2', models.BinaryField(blank=True, null=True)),
                ('fingerleft', models.IntegerField(blank=True, null=True)),
                ('fingerprintl1', models.BinaryField(blank=True, null=True)),
                ('fingerprintl2', models.BinaryField(blank=True, null=True)),
                ('imagedocument', models.BinaryField(blank=True, null=True)),
                ('datebiometric', models.DateField(blank=True, null=True)),
                ('typeprocessbiometric', models.IntegerField(blank=True, null=True)),
                ('imagedocument1', models.BinaryField(blank=True, null=True)),
                ('institutional', models.BooleanField(blank=True, null=True)),
                ('levelcontributory', models.IntegerField(blank=True, null=True)),
                ('typecontributory', models.IntegerField(blank=True, null=True)),
                ('typeeducationid', models.IntegerField(blank=True, null=True)),
                ('epsid', models.BigIntegerField(blank=True, null=True)),
                ('eps', models.BooleanField(blank=True, null=True)),
                ('pension', models.BooleanField(blank=True, null=True)),
                ('funeralsecure', models.BooleanField(blank=True, null=True)),
                ('phonecompany', models.CharField(blank=True, max_length=40, null=True)),
                ('egress', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('stratum', models.CharField(blank=True, max_length=1, null=True)),
                ('assets', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('passives', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('patrimony', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('typemediaid', models.IntegerField(blank=True, null=True)),
                ('projectid', models.IntegerField(blank=True, null=True)),
                ('genreid', models.IntegerField(blank=True, null=True)),
                ('automaticpayment', models.BooleanField(blank=True, null=True)),
                ('associateentrydate', models.DateField(blank=True, null=True)),
                ('associateretirementdate', models.DateField(blank=True, null=True)),
                ('cardreference', models.CharField(blank=True, max_length=30, null=True)),
                ('pep', models.BooleanField(blank=True, null=True)),
                ('observation', models.CharField(blank=True, max_length=4000, null=True)),
                ('risk', models.CharField(blank=True, max_length=1, null=True)),
                ('typemedicineid', models.IntegerField(blank=True, null=True)),
                ('commercialregistration', models.CharField(blank=True, max_length=25, null=True)),
                ('contractor', models.BooleanField(blank=True, null=True)),
                ('liquidatorbase', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('salary', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('typereference', models.CharField(blank=True, max_length=5, null=True)),
                ('network', models.BooleanField(blank=True, null=True)),
                ('isebill', models.BooleanField(blank=True, null=True)),
                ('lastsale', models.DateField(blank=True, null=True)),
                ('typecontactid', models.IntegerField(blank=True, null=True)),
                ('habeasdata', models.BooleanField(blank=True, null=True)),
                ('coffeefreight', models.CharField(blank=True, max_length=1, null=True)),
                ('ean', models.BigIntegerField(blank=True, null=True)),
                ('typeemployee', models.CharField(blank=True, max_length=3, null=True)),
                ('formliquidationid', models.IntegerField(blank=True, null=True)),
                ('timezone', models.CharField(blank=True, max_length=30, null=True)),
                ('populationgroupmethodology', models.CharField(blank=True, max_length=2, null=True)),
                ('subgroupsisbeniv', models.CharField(blank=True, max_length=3, null=True)),
                ('dispersion', models.CharField(blank=True, max_length=2, null=True)),
                ('solidaritycontribution', models.BooleanField(blank=True, null=True)),
            ],
            options={
                'db_table': 'client',
                'managed': False,
            },
        ),
        migrations.AddConstraint(
            model_name='documenttype',
            constraint=models.UniqueConstraint(fields=('type_id',), name='UNQ_document_type_id'),
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         6/03/23 14:29
# Project:      CFHL Transactional Backend
# Module Name:  admin_views
# Description:
# ****************************************************************
from django.contrib import admin
from django.utils.translation import gettext_lazy as _


class StateMachineAdmin(admin.ModelAdmin):
    list_display = ("state", "from_state", "is_initial", "is_final", "update_oasis")
    fieldsets = (
        (
            _("Status Section"),
            {
                "fields": (("state", "from_state"), ("oasis_state", "oasis_status"),
                           ("is_initial", "is_final", "is_changed", "update_oasis"),
                           ("timeout", "state_at_timeout"))
            }
        ),
        (
            _("Notifications Section"),
            {
                "fields": (("notify_user", "notify_coffee_area", "notify_legal_area", "send_contract"),)
            }
        )

    )



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         17/01/23 4:48 PM
# Project:      CFHL Transactional Backend
# Module Name:  sync_document_types
# Description:
# ****************************************************************
from core import celery_app
from oasis import models
from typing import Any


@celery_app.task(bind=True)
def sync_document_types(app: Any):
    try:
        qs = models.TypeClient.objects.get_for_sync()
        if qs:
            for type_client in qs:
                models.DocumentType.objects.save_or_create(type_id=type_client.get("typeclientid"),
                                                           description=type_client.get("typeclientname"))
    except Exception as exc:
        pass



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         1/03/23 11:45
# Project:      CFHL Transactional Backend
# Module Name:  oasis_associate_balance
# Description:
# ****************************************************************
from datetime import timedelta
from django.utils import timezone
from zibanu.django.db import models


class AssociateBalance(models.Manager):
    def get_quota(self, customer_id: int, year: int = None, month: int = None) -> float:
        now = timezone.now() + timedelta(days=-30)
        # Set year and month
        if year is None:
            year = now.year
        if month is None:
            month = now.month

        # Get QUOTA
        record = self.filter(clientid__exact=customer_id, year__exact=year, period__exact=month).first()
        if record is not None:
            quota = record.areacoffeeproductive
        else:
            quota = 0

        return quota



# Generated by Django 4.1.7 on 2023-03-04 03:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0011_offer_statemachine_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='offer',
            name='price',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=7, verbose_name='Price'),
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         16/11/22 2:39 PM
# Project:      CFHL Transactional Backend
# Module Name:  discount
# Description:
# ****************************************************************
from django.conf import settings
from django.utils import timezone
from datetime import datetime
from zibanu.django.utils import change_timezone
from zibanu.django.db import models


class OasisDiscount(models.Manager):
    """
    Custom manager for entity Discount
    """

    def get_price(self, product_code: int, discount_list: list = []) -> dict:
        """
        Method to obtain a dictionary with price and valid range keys.
        :param product_code: code of product to obtain price
        :param discount_list: list of discounts to add if exists
        :return:
        """
        price_dict = {
            "date_from": None,
            "date_to": None,
            "price": 0
        }
        base_product = settings.OASIS_COFFEE_BASE_PRODUCT
        base_discount = settings.OASIS_COFFEE_BASE_DISCOUNT

        if product_code is not None:
            # Get Base Price
            discount = self.get_product_discounts(product_code=base_product, discount=base_discount)
            if discount is not None:
                price_dict["price"] = discount.price
                price_dict["date_from"] = change_timezone(discount.dateinitial)
                price_dict["date_to"] = change_timezone(discount.datefinal)
                # If Product is different from base
                if product_code != base_product:
                    discount = self.get_product_discounts(product_code=product_code, discount=base_discount)
                    # If product has own base price
                    if discount is not None:
                        price_dict["price"] = discount.price

                    for discount_item in discount_list:
                        # Get another discounts if exists.
                        discount = self.get_product_discounts(product_code=product_code, discount=discount_item)
                        if discount is not None:
                            price_dict["price"] += discount.price

        # Round a price to 0 decimals before ret
        price_dict["price"] = round(price_dict["price"])
        return price_dict

    def get_product_discounts(self, product_code: int = 0, discount: int = 0) -> models.Model:
        """
        Method to get discount price for a product.
        :param product_code: product id, default = 0
        :param discount: discount id, default = 0
        :return:
        """
        # Get default Location
        location = settings.OASIS_DEFAULT_LOCATION
        try:
            # Get a naive datetime
            now = datetime.now()
            # Create a queryset with filter options
            queryset = self.get_queryset().filter(productid__exact=product_code, typediscountid__exact=discount,
                                                  locationid__exact=location)
            # Exclude nulls
            queryset = queryset.exclude(dateinitial=None)
            # Add datetime option to queryset
            queryset = queryset.filter(
                dateinitial__lte=datetime(year=now.year, month=now.month, day=now.day, hour=now.hour, minute=now.minute,
                                          tzinfo=timezone.utc),
                datefinal__gte=datetime(year=now.year, month=now.month, day=now.day, hour=now.hour, minute=now.minute,
                                        tzinfo=timezone.utc)).order_by("-dateinitial")
            base_price = queryset.first()
        except Exception as exc:
            raise Exception from exc
        else:
            return base_price



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         17/01/23 5:07 PM
# Project:      CFHL Transactional Backend
# Module Name:  document_type
# Description:
# ****************************************************************
from zibanu.django.db import models


class DocumentType(models.Manager):

    def get_record_by_type(self, type_id: str = None) -> models.QuerySet:
        return self.get_queryset().filter(type_id__exact=type_id)

    def save_or_create(self, type_id: str = None, description: str = None) -> bool:
        try:
            qs = self.get_record_by_type(type_id=type_id)
            if qs.count() == 0:
                document_type = self.model()
                document_type.type_id = type_id
                document_type.description = description
            else:
                document_type = qs.get()
                document_type.description = description
            document_type.save()
        except Exception:
            b_return = False
        else:
            b_return = True
        finally:
            return b_return






# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         26/02/23 15:43
# Project:      CFHL Transactional Backend
# Module Name:  oasis_statuses
# Description:
# ****************************************************************
from django.conf import settings
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _


def validate_oasis_statuses(value: str) -> None:
    if value not in settings.COFFEE_OFFERS_STATUSES:
        raise ValidationError(_("Invalid Coffe Order - Oasis Status"))



# Generated by Django 4.1.5 on 2023-01-27 03:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0003_oasiscompany_company'),
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('plan', models.IntegerField()),
                ('accountid', models.BigIntegerField()),
                ('accountname', models.CharField(blank=True, max_length=100, null=True)),
                ('level', models.IntegerField(blank=True, null=True)),
                ('parent', models.BigIntegerField(blank=True, null=True)),
                ('nature', models.CharField(blank=True, max_length=1, null=True)),
                ('impute', models.BooleanField(blank=True, null=True)),
                ('client', models.BooleanField(blank=True, null=True)),
                ('costcenter', models.BooleanField(blank=True, null=True)),
                ('business', models.BooleanField(blank=True, null=True)),
                ('project', models.BooleanField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=1, null=True)),
                ('retention', models.BooleanField(blank=True, null=True)),
                ('percentageretention', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('reference', models.BooleanField(blank=True, null=True)),
                ('adjustment', models.BooleanField(blank=True, null=True)),
                ('adjustmentaccount1', models.BigIntegerField(blank=True, null=True)),
                ('adjustmentaccount2', models.BigIntegerField(blank=True, null=True)),
                ('repetitive', models.BooleanField(blank=True, null=True)),
                ('repetitiveaccount1', models.BigIntegerField(blank=True, null=True)),
                ('repetitiveaccount2', models.BigIntegerField(blank=True, null=True)),
                ('status', models.CharField(blank=True, max_length=1, null=True)),
                ('utility', models.BooleanField(blank=True, null=True)),
                ('module', models.CharField(blank=True, max_length=1, null=True)),
                ('currency', models.CharField(blank=True, max_length=1, null=True)),
                ('currencyid', models.IntegerField(blank=True, null=True)),
                ('baseretention', models.BooleanField(blank=True, null=True)),
                ('percentagebudget', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('oldcode', models.CharField(blank=True, max_length=20, null=True)),
                ('budget', models.BooleanField(blank=True, null=True)),
                ('budgetcontrol', models.BooleanField(blank=True, null=True)),
                ('order', models.BigIntegerField(blank=True, null=True)),
                ('alternatecode', models.CharField(blank=True, max_length=20, null=True)),
                ('expenseobjectid', models.IntegerField(blank=True, null=True)),
                ('entryid', models.IntegerField(blank=True, null=True)),
                ('ordinary', models.CharField(blank=True, max_length=1, null=True)),
                ('accountname1', models.CharField(blank=True, max_length=100, null=True)),
                ('abc', models.CharField(blank=True, max_length=1, null=True)),
                ('bookid', models.IntegerField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('product', models.BooleanField(blank=True, null=True)),
                ('codeid', models.CharField(blank=True, max_length=3, null=True)),
                ('tax', models.CharField(blank=True, max_length=1, null=True)),
                ('businessid', models.IntegerField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('taxtypeid', models.IntegerField(blank=True, null=True)),
                ('quantitytype', models.CharField(blank=True, max_length=1, null=True)),
            ],
            options={
                'db_table': 'account',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='VAccountingBalanceClient',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('company_id', models.IntegerField(db_column='companyid')),
                ('client_id', models.BigIntegerField(db_column='clientid')),
                ('year', models.IntegerField()),
                ('period', models.IntegerField()),
                ('plan', models.IntegerField()),
                ('account_id', models.BigIntegerField(db_column='accountid')),
                ('book_id', models.IntegerField(db_column='bookid')),
                ('debit', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('credit', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('balance', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('debit_base', models.DecimalField(blank=True, db_column='debitbase', decimal_places=4, max_digits=19, null=True)),
                ('credit_base', models.DecimalField(blank=True, db_column='creditbase', decimal_places=4, max_digits=19, null=True)),
                ('balance_base', models.DecimalField(blank=True, db_column='balancebase', decimal_places=4, max_digits=19, null=True)),
            ],
            options={
                'db_table': 'v_AccountingBalanceClient',
                'managed': False,
            },
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-01 16:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0008_location_coffeewarehouse_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Associatebalance',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('period', models.IntegerField()),
                ('year', models.IntegerField()),
                ('clientid', models.BigIntegerField()),
                ('contributionvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributionyearvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributiontotalvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('salesvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('receivablesexpiredvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('otherexpiredvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('anticipationexpiredvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contribution', models.BooleanField(blank=True, null=True)),
                ('contributionyear', models.BooleanField(blank=True, null=True)),
                ('sales', models.BooleanField(blank=True, null=True)),
                ('receivablesexpired', models.BooleanField(blank=True, null=True)),
                ('otherexpired', models.BooleanField(blank=True, null=True)),
                ('anticipationexpired', models.BooleanField(blank=True, null=True)),
                ('able', models.BooleanField(blank=True, null=True)),
                ('cosigner', models.BooleanField(blank=True, null=True)),
                ('purchasefuture', models.BooleanField(blank=True, null=True)),
                ('kiloscoffeegreen', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('almondsound', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('almonddefect', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('areacoffeetotal', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('areacoffeeproductive', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributionbalance', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('assembly', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('revaluation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('solidarity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('contributionbalancepay', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('observation', models.CharField(blank=True, max_length=4000, null=True)),
                ('billing', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
            ],
            options={
                'db_table': 'associatebalance',
                'managed': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         6/03/23 13:54
# Project:      CFHL Transactional Backend
# Module Name:  offers_serializer
# Description:
# ****************************************************************
from oasis.models import Offer
from zibanu.django.rest_framework import serializers


class OfferListSerializer(serializers.ModelSerializer):
    created_at = serializers.DateTimeField(format="%Y-%m-%d")
    warehouse = serializers.CharField(source="warehouse.location_name")
    status_desc = serializers.SerializerMethodField()
    product = serializers.CharField(source="product.name")

    def get_status_desc(self, instance):
        return instance.get_status_display()

    class Meta:
        model = Offer
        fields = ("id", "contract", "created_at", "delivery_date", "kg_offered", "kg_received", "price",
                  "warehouse", "status", "status_desc", "product")




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         10/12/22 3:52 PM
# Project:      CFHL Transactional Backend
# Module Name:  __init__.py
# Description:
# ****************************************************************
from .sync_coffee_ware_house import sync_coffee_ware_house
from .sync_company import sync_company
from .sync_document_types import sync_document_types
from .sync_products import sync_products

__all__ = [
    "sync_coffee_ware_house",
    "sync_products",
    "sync_company",
    "sync_document_types"
]



# Generated by Django 4.1.7 on 2023-03-04 03:34

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import oasis.coffee_offers.lib.validators.date_validators
import oasis.coffee_offers.lib.validators.oasis_statuses


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('oasis', '0010_operation'),
    ]

    operations = [
        migrations.CreateModel(
            name='Offer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('modified_at', models.DateTimeField(auto_now=True, verbose_name='Modified at')),
                ('contract', models.IntegerField(verbose_name='Contract No')),
                ('kg_offered', models.DecimalField(decimal_places=2, max_digits=9, verbose_name='Kg Offered')),
                ('kg_received', models.DecimalField(decimal_places=2, default=0, max_digits=9, verbose_name='Kg Received')),
                ('status', models.IntegerField(choices=[(0, 'New'), (1, 'Approved'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], default=0, verbose_name='Status')),
                ('delivery_date', models.DateField(validators=[oasis.coffee_offers.lib.validators.date_validators.greater_than_today], verbose_name='Delivery Date')),
            ],
        ),
        migrations.CreateModel(
            name='StateMachine',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state', models.IntegerField(choices=[(0, 'New'), (1, 'Approved'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], default=0, verbose_name='State')),
                ('from_state', models.IntegerField(blank=True, choices=[(0, 'New'), (1, 'Approved'), (2, 'Signed'), (3, 'Partial'), (4, 'Finished'), (9, 'Rejected')], null=True, verbose_name='From State')),
                ('oasis_state', models.CharField(max_length=1, verbose_name='Oasis State')),
                ('oasis_status', models.CharField(max_length=1, validators=[oasis.coffee_offers.lib.validators.oasis_statuses.validate_oasis_statuses], verbose_name='Oasis Status')),
                ('notify_user', models.BooleanField(default=True, verbose_name='Notify User')),
                ('notify_coffee_area', models.BooleanField(default=False, verbose_name='Notify Coffee Area')),
                ('notify_legal_area', models.BooleanField(default=False, verbose_name='Notify Legal Area')),
            ],
        ),
        migrations.AddConstraint(
            model_name='statemachine',
            constraint=models.UniqueConstraint(fields=('state', 'from_state'), name='UNQ_CoffeeOffer_StateMachine'),
        ),
        migrations.AddField(
            model_name='offer',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='oasis.product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='offer',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='offers', related_query_name='user', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='offer',
            name='warehouse',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_query_name='warehouses', to='oasis.coffeewarehouse', verbose_name='Warehouse'),
        ),
        migrations.AddConstraint(
            model_name='offer',
            constraint=models.UniqueConstraint(fields=('contract',), name='UNQ_Offer_Contract'),
        ),
    ]



# Generated by Django 4.1.5 on 2023-02-05 00:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0005_delete_vaccountingbalanceclient_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Periods',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('year', models.IntegerField()),
                ('period', models.IntegerField()),
                ('final', models.DateField(blank=True, null=True)),
                ('open', models.BooleanField(blank=True, null=True)),
                ('plan', models.IntegerField()),
                ('weeks', models.IntegerField(blank=True, null=True)),
                ('fiscalperiod', models.IntegerField(blank=True, null=True)),
                ('fiscalyear', models.IntegerField(blank=True, null=True)),
                ('inflation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('interes', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budgetperiod', models.IntegerField(blank=True, null=True)),
                ('budgetyear', models.IntegerField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'periods',
                'managed': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         23/02/23 10:12
# Project:      CFHL Transactional Backend
# Module Name:  urls
# Description:
# ****************************************************************
from oasis.coffee_offers.api import services
from django.urls import path
from rest_framework.routers import DefaultRouter

routers = DefaultRouter()

urlpatterns = [
    path(r"pre-load/", services.CoffeeOffers.as_view({"post": "pre_load"})),
    path(r"load/", services.CoffeeOffers.as_view({"post": "load_offer"})),
    path(r"change-status/", services.CoffeeOffers.as_view({"post": "change_status"})),
    path(r"sign/", services.CoffeeOffers.as_view({"post": "sign_offer"}))
]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         6/03/23 14:36
# Project:      CFHL Transactional Backend
# Module Name:  admin
# Description:
# ****************************************************************
from django.contrib import admin
from oasis.coffee_offers.admin_views import StateMachineAdmin
from oasis.models import StateMachine

admin.site.register(StateMachine, StateMachineAdmin)



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         1/03/23 10:10
# Project:      CFHL Transactional Backend
# Module Name:  coffee_offers
# Description:
# ****************************************************************
from coffee_price.models import Price
from coffee_price.api.serializers import PriceListSerializer
from datetime import datetime
from datetime import timedelta
from django.conf import settings
from django.core.cache import cache
from django.core.exceptions import ValidationError as CoreValidationError
from django.utils import timezone
from django.utils.translation import gettext_lazy as _
from oasis.coffee_offers.api.serializers import CoffeeWareHouseListSerializer
from oasis.coffee_offers.api.serializers import OfferListSerializer
from oasis.lib.choices import CustomerType
from oasis.lib.utils import OasisActions
from oasis.models import AssociateBalance
from oasis.models import CoffeeWareHouse
from oasis.models import Offer
from oasis_auth.lib.utils import SendCode
from rest_framework import status
from rest_framework.response import Response
from zibanu.django.rest_framework.exceptions import APIException
from zibanu.django.rest_framework.exceptions import ValidationError
from zibanu.django.rest_framework import viewsets
from zibanu.django.utils import CodeGenerator
from zibanu.django.utils import ErrorMessages


class CoffeeOffers(viewsets.ViewSet):
    """
    View set for rest service of CoffeOffers module
    """
    __cache_timeout = settings.OASIS_AUTH_CODE_TIMEOUT
    __cache_timeout_seconds = __cache_timeout * 60

    def _get_quota(self, user) -> float:
        """
        Method to get a quota from user profile
        :param user: user object from request
        :return: calculated quota
        """
        # Calculate QUOTA in Kg.
        if user.profile.segment == settings.COFFEE_OFFERS_TRADER_SEGMENT:
            quota = settings.COFFEE_OFFERS_TRADER_QUOTA
        else:
            if user.profile.type == CustomerType.PARTNER:
                quota = AssociateBalance.objects.get_quota(user.profile.document_id)
            else:
                quota = settings.COFFEE_OFFERS_DEFAULT_QUOTA

        if settings.COFFEE_OFFERS_CALCULATE_QUOTA:
            quota = quota - Offer.objects.get_balance(user)

        # Round quota
        quota = int(round(quota / settings.COFFEE_OFFERS_ROUND_FACTOR)) * settings.COFFEE_OFFERS_ROUND_FACTOR
        return quota

    def _get_active_offers_count(self, user) -> int:
        """
        REturn active offers counter
        :param user: owner of offers
        :return: counter
        """
        qs = Offer.objects.get_active_offers(user=user)
        return qs.count()

    def pre_load(self, request) -> Response:
        """
        Rest service for preload all data required for frontend operation.
        :param request: request object from HTTP
        :return: Response object
        """
        try:
            now = timezone.now()
            to_date = now + timedelta(days=settings.COFFEE_OFFERS_DAYS_DELTA)
            product_list =[int(x) for x in settings.COFFEE_OFFERS_PRODUCT_LIST.split(",")]
            user = self._get_user(request)
            # Validate EXCLUDED
            if settings.COFFEE_OFFERS_LOCKED_SEGMENT != 0 and user.profile.segment == settings.COFFEE_OFFERS_LOCKED_SEGMENT:
                raise ValidationError(_("The partner/client is locked for coffee offers."))
            # Load Price List
            price_qs = Price.objects.get_products_price_by_date(date_to_search=now, product_list=product_list)
            price_serializer = PriceListSerializer(instance=price_qs, many=True,
                                                   context={"kg": True, "factor": settings.COFFEE_OFFERS_FACTOR})
            # Load Warehouse List
            warehouse_qs = CoffeeWareHouse.objects.order_by("location_name").all()
            warehouse_serializer = CoffeeWareHouseListSerializer(instance=warehouse_qs, many=True)
            # Load Offer List
            offer_qs = Offer.objects.get_active_offers(user=user)
            offer_serializer = OfferListSerializer(instance=offer_qs, many=True)

            # Calculate QUOTA in Kg.

            data_return = {
                "quota": self._get_quota(user),
                "percent": settings.COFFEE_OFFERS_PRICE_DELTA,
                "to_date": to_date,
                "offers": offer_serializer.data,
                "prices": price_serializer.data,
                "warehouses": warehouse_serializer.data
            }
            status_return = status.HTTP_200_OK
        except ValidationError as exc:
            raise APIException(error=exc.detail[0], http_status=status.HTTP_406_NOT_ACCEPTABLE) from exc
        except Exception as exc:
            raise APIException(error=str(exc), http_status=status.HTTP_500_INTERNAL_SERVER_ERROR) from exc
        else:
            return Response(status=status_return, data=data_return)

    def load_offer(self, request) -> Response:
        """
        REST service to load offer and set it pending to sign.
        :param request: request object from HTTP
        :return: Response object
        """
        try:
            if {"product", "price", "amount", "location", "to_date"} <= request.data.keys():
                today = datetime.now()
                user = self._get_user(request)
                to_date = datetime.strptime(request.data.get("to_date"), "%Y-%m-%d")

                # Validate user segment and user quota.
                if request.data.get("amount") >= self._get_quota(user):
                    raise ValidationError(_("The amount exceeds the quota available."))
                if user.profile.segment == settings.COFFEE_OFFERS_LOCKED_SEGMENT:
                    raise ValidationError(_("The partner/client is locked for coffee offers."))
                if (to_date - today) > timedelta(days=settings.COFFEE_OFFERS_DAYS_DELTA):
                    raise ValidationError(
                        _("Delivery date is greater than %s days" % settings.COFFEE_OFFERS_DAYS_DELTA))
                if self._get_active_offers_count(user=user) >= settings.COFFEE_OFFERS_MAX_ACTIVE:
                    raise ValidationError(_("You have reached max active offers quota."))

                code_generator = CodeGenerator("save_offer")
                data_cache = code_generator.generate_dict()
                cache_key = data_cache.pop("uuid").hex
                data_cache["user"] = user
                data_cache["data"] = {
                    "product": request.data.get("product"),
                    "price": request.data.get("price"),
                    "amount": request.data.get("amount"),
                    "location": request.data.get("location"),
                    "to_date": request.data.get("to_date")
                }
                email_context = {
                    "customer_name": user.get_full_name(),
                    "customer_code": data_cache.get("code"),
                }
                data_return = {
                    "token": cache_key
                }
                send_code = SendCode(to=user.email, action=data_cache.get("action"), context=email_context)
                if send_code.load_templates():
                    send_code.send()
                cache.set(cache_key, data_cache, self.__cache_timeout_seconds)
                status_return = status.HTTP_200_OK
            else:
                raise ValidationError(ErrorMessages.DATA_REQUEST_NOT_FOUND)
        except (ValidationError, CoreValidationError) as exc:
            raise APIException(error=exc.detail[0], http_status=status.HTTP_406_NOT_ACCEPTABLE) from exc
        except Exception as exc:
            raise APIException(error=str(exc), http_status=status.HTTP_500_INTERNAL_SERVER_ERROR) from exc
        else:
            return Response(status=status_return, data=data_return)

    def change_status(self, request) -> Response:
        try:
            if {"offer_id", "status"} <= request.data.keys():
                user = self._get_user(request)
                code_generator = CodeGenerator("change_status")
                data_cache = code_generator.generate_dict()
                cache_key = data_cache.pop("uuid").hex
                data_cache["user"] = user
                data_cache["data"] = {
                    "offer_id": request.data.get("offer_id"),
                    "status": request.data.get("status")
                }
                data_return = {
                    "token": cache_key
                }
                email_context = {
                    "customer_name": user.get_full_name(),
                    "customer_code": data_cache.get("code")
                }
                send_code = SendCode(to=user.email, action=data_cache.get("action"), context=email_context)
                if send_code.load_templates():
                    send_code.send()
                cache.set(cache_key, data_cache, self.__cache_timeout_seconds)
                status_return = status.HTTP_200_OK
            else:
                raise ValidationError(ErrorMessages.DATA_REQUEST_NOT_FOUND)
        except Exception as exc:
            raise APIException(error=str(exc), http_status=status.HTTP_500_INTERNAL_SERVER_ERROR) from exc
        else:
            return Response(status=status_return, data=data_return)

    def sign_offer(self, request) -> Response:
        """
        Sign an offer with electronic code and run specific action
        :param request: request object from HTTP
        :return: response object
        """
        try:
            if {"token", "code"} <= request.data.keys():
                user = self._get_user(request)
                data_cache = cache.get(request.data.get("token"))
                if data_cache:
                    if request.data.get("code") == data_cache.get("code") and user == data_cache.get("user"):
                        oasis_actions = OasisActions(data_cache=data_cache)
                        result = oasis_actions.do_action()
                    else:
                        raise ValidationError(_("Code or user does not match."))
                else:
                    raise ValidationError(_("The code has expired. You have to create the offer again."))
                status_return = status.HTTP_200_OK
            else:
                raise ValidationError(ErrorMessages.DATA_REQUEST_NOT_FOUND)
        except CoreValidationError as exc:
            raise APIException(error=exc.message, http_status=status.HTTP_406_NOT_ACCEPTABLE)
        except ValidationError as exc:
            raise APIException(error=exc.detail[0], http_status=status.HTTP_406_NOT_ACCEPTABLE) from exc
        except Exception as exc:
            raise APIException(error=str(exc), http_status=status.HTTP_500_INTERNAL_SERVER_ERROR) from exc
        else:
            return Response(status=status_return)



# -*- coding: utf-8 -*-

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         16/03/23 16:18
# Project:      CFHL Transactional Backend
# Module Name:  on_post_save_offer
# Description:
# ****************************************************************
from django.db.models.signals import post_save
from django.dispatch import receiver
from oasis.models import Offer
from oasis.models import OfferMov


@receiver(post_save, sender=Offer)
def on_post_save_offer(sender, **kwargs):
    """
    Event for signal post_save on Offer model.
    """
    instance = kwargs.get("instance", None)
    created = kwargs.get("created", False)
    offer_mov = OfferMov(offer=instance, status=instance.status, delivery_date=instance.delivery_date, price=instance.price, kg_offered=instance.kg_offered, kg_received=instance.kg_received, created=created)
    offer_mov.save()



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         14/12/22 2:55 PM
# Project:      CFHL Transactional Backend
# Module Name:  product
# Description:
# ****************************************************************
from oasis import models
from zibanu.django.rest_framework import serializers


class ProductListSerializer(serializers.ModelSerializer):
    """
    Serializer class for list of products for frontend choices.
    """

    class Meta:
        model = models.Product
        fields = ("id", "name")




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         1/03/23 12:04
# Project:      CFHL Transactional Backend
# Module Name:  offer
# Description:
# ****************************************************************
from oasis.coffee_offers.lib.choices import CoffeeOffersStates
from zibanu.django.db import models
from typing import Any


class Offer(models.Manager):
    """
    Manager class for Offer entity
    """
    def get_balance(self, user: Any) -> float:
        """
        Method to return a balance from active offers in entity
        :param user: Offers owner
        :return: balance
        """
        qs = self.get_active_offers(user)
        balance = 0
        if qs is not None:
            for offer in qs:
                balance = balance + (offer.kg_offered - offer.kg_received)
        return balance

    def get_active_offers(self, user: Any) -> models.QuerySet:
        """
        Method to return a queryset with only active offers
        :param user: Offers owner
        :return: filtered queryset
        """
        states = CoffeeOffersStates.not_ended_list()

        qs = self.filter(user__exact=user, status__in=states)

        return qs

    def get_all_active_offers(self):
        return self.filter(status__in=CoffeeOffersStates.not_ended_list())



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         16/11/22 9:12 AM
# Project:      CFHL Transactional Backend
# Module Name:  apps
# Description:
# ****************************************************************
from django.conf import settings
from django.apps import AppConfig


class OasisConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'oasis'

    def ready(self):
        """
        Event that is fired when the module loads correctly.
        :return:
        """
        settings.OASIS_COFFEE_BASE_PRODUCT = getattr(settings, "OASIS_COFFEE_BASE_PRODUCT", 0)
        settings.OASIS_COFFEE_BASE_DISCOUNT = getattr(settings, "OASIS_COFFEE_BASE_DISCOUNT", 2)
        settings.OASIS_COFFEE_PRODUCT_CLASSIFICATION_ID = getattr(settings, "OASIS_COFFEE_PRODUCT_CLASSIFICATION_ID", 1111)
        settings.OASIS_DEFAULT_LOCATION = getattr(settings, "OASIS_DEFAULT_LOCATION", 0)
        settings.OASIS_DEFAULT_COMPANY = getattr(settings, "OASIS_DEFAULT_COMPANY", 1)
        settings.OASIS_DEFAULT_COMPANY_ID = getattr(settings, "OASIS_DEFAULT_COMPANY_ID", 891100296)




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         20/12/22 6:35 AM
# Project:      CFHL Transactional Backend
# Module Name:  customer_type
# Description:
# ****************************************************************
from django.utils.translation import gettext_lazy as _
from zibanu.django.db import models


class CustomerType(models.IntegerChoices):
    """
    Customer types to work
    """
    ANYTHING = 0, _("Not bound")
    CUSTOMER = 1, _("Customer")
    PARTNER = 2, _("Partner")


# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         24/01/23 6:34 PM
# Project:      CFHL Transactional Backend
# Module Name:  oasis_company
# Description:
# ****************************************************************
from oasis import models as oasis_models
from zibanu.django.db import models
from zibanu.django.db.models import Subquery, OuterRef


class OasisCompany(models.Manager):
    def get_for_sync(self):
        qs = self.model.objects.annotate(
            representative=Subquery(
                oasis_models.Client.objects.filter(clientid__exact=OuterRef("clientid")).values("representative")[:1]
            )
        ).values("companyid", "companyname", "companycode", "address", "phone", "city", "representative").all()
        return qs




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         10/12/22 4:53 PM
# Project:      CFHL Transactional Backend
# Module Name:  own_product
# Description:
# ****************************************************************
from zibanu.django.db import models


class Product(models.Manager):

    def get_by_product(self, product_id: int) -> models.Model:
        """
        Return a product record based on id received by parameters
        :param product_id: product id
        :return: product record
        """
        return self.get_queryset().filter(product_id__exact=product_id).get()

    def get_by_products(self, product_list: list) -> models.QuerySet:
        """
        Return a set of records based on product list received by parameters
        :param product_list: product list
        :return: queryset with set of records
        """
        return self.get_queryset().filter(product_id__in=product_list)




# Generated by Django 4.1.5 on 2023-01-26 02:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0002_geographiclocation_typeclient_documenttype_client_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='OasisCompany',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('companyname', models.CharField(max_length=100)),
                ('companycode', models.CharField(max_length=30)),
                ('countryid', models.IntegerField()),
                ('clientid', models.BigIntegerField()),
                ('liquidation', models.CharField(blank=True, max_length=1, null=True)),
                ('retentioninvoice', models.BooleanField(blank=True, null=True)),
                ('languageid', models.IntegerField(blank=True, null=True)),
                ('address', models.CharField(blank=True, max_length=100, null=True)),
                ('address1', models.CharField(blank=True, max_length=100, null=True)),
                ('phone', models.CharField(blank=True, max_length=100, null=True)),
                ('city', models.CharField(blank=True, max_length=100, null=True)),
                ('state', models.CharField(blank=True, max_length=100, null=True)),
                ('rounding', models.BooleanField(blank=True, null=True)),
                ('typerounding', models.CharField(blank=True, max_length=1, null=True)),
                ('partialdispatch', models.BooleanField(blank=True, null=True)),
                ('typeprice', models.CharField(blank=True, max_length=1, null=True)),
                ('validatecredit', models.BooleanField(blank=True, null=True)),
                ('discountorder', models.BooleanField(blank=True, null=True)),
                ('discountvolume', models.BooleanField(blank=True, null=True)),
                ('discountlocation', models.BooleanField(blank=True, null=True)),
                ('discountpromptpayment', models.BooleanField(blank=True, null=True)),
                ('creditunit', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('local_check', models.BooleanField(blank=True, db_column='check', null=True)),
                ('local_delay', models.BooleanField(blank=True, db_column='delay', null=True)),
                ('limit', models.BooleanField(blank=True, null=True)),
                ('interest', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('delayinterest', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('sanctioncheck', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('suspensionrate', models.CharField(blank=True, max_length=1, null=True)),
                ('legalrate', models.CharField(blank=True, max_length=1, null=True)),
                ('fiscalperiod', models.IntegerField(blank=True, null=True)),
                ('physical', models.CharField(blank=True, max_length=1, null=True)),
                ('transit', models.BooleanField(blank=True, null=True)),
                ('costmethod', models.CharField(blank=True, max_length=1, null=True)),
                ('costsystem', models.CharField(blank=True, max_length=1, null=True)),
                ('costmodel', models.CharField(blank=True, max_length=1, null=True)),
                ('periodconsumption', models.IntegerField(blank=True, null=True)),
                ('coststore', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('costpurchase', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('receipttolerance', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('margin', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quotation', models.IntegerField(blank=True, null=True)),
                ('transporter', models.BooleanField(blank=True, null=True)),
                ('risckentity', models.BigIntegerField(blank=True, null=True)),
                ('compensationentity', models.BigIntegerField(blank=True, null=True)),
                ('autoliquidation', models.CharField(blank=True, max_length=1, null=True)),
                ('paymentlocationid', models.IntegerField(blank=True, null=True)),
                ('associatequota', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('locationjournalid', models.IntegerField(blank=True, null=True)),
                ('creditretention', models.BooleanField(blank=True, null=True)),
                ('validatecreditremission', models.BooleanField(blank=True, null=True)),
                ('dispatch', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('approveorder', models.BooleanField(blank=True, null=True)),
                ('budgetquantity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('budgetvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('changepriceinvoiceorder', models.BooleanField(blank=True, null=True)),
                ('factoradd', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('factorsubstraction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('supercode', models.CharField(blank=True, max_length=6, null=True)),
                ('pricetypefrequent', models.IntegerField(blank=True, null=True)),
                ('exchangeratevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('exchangerate', models.BooleanField(blank=True, null=True)),
                ('pricemaximum', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('extcode', models.CharField(blank=True, max_length=13, null=True)),
                ('associateinterest', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('loaninteres', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('programproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('planproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('estandarproduction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumsupervisor', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumoperator', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumattendant', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumsupervisorsupport', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('premiumassistant', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('attendantid', models.BigIntegerField(blank=True, null=True)),
                ('supervisorsupport', models.BigIntegerField(blank=True, null=True)),
                ('attendantmix', models.BigIntegerField(blank=True, null=True)),
                ('periodsrotation', models.IntegerField(blank=True, null=True)),
                ('cashpaymentid', models.IntegerField(blank=True, null=True)),
                ('dynamicweight', models.BooleanField(blank=True, null=True)),
                ('accountpayroll', models.CharField(blank=True, max_length=1, null=True)),
                ('costproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('methodcommision', models.CharField(blank=True, max_length=1, null=True)),
                ('security', models.BigIntegerField(blank=True, null=True)),
                ('assetorder', models.BooleanField(blank=True, null=True)),
                ('pricefreight', models.BooleanField(blank=True, null=True)),
                ('picking', models.BooleanField(blank=True, null=True)),
                ('localizationabc', models.BooleanField(blank=True, null=True)),
                ('mobile', models.BooleanField(blank=True, null=True)),
                ('receivelocalization', models.CharField(blank=True, max_length=20, null=True)),
                ('dispatchlocalization', models.CharField(blank=True, max_length=20, null=True)),
                ('packinglocalization', models.CharField(blank=True, max_length=20, null=True)),
                ('accounttax', models.BooleanField(blank=True, null=True)),
                ('accounttaxpurchase', models.BooleanField(blank=True, null=True)),
                ('efficiency', models.BooleanField(blank=True, null=True)),
                ('approvedispatch', models.BooleanField(blank=True, null=True)),
                ('matrixid', models.IntegerField(blank=True, null=True)),
                ('generateprice', models.BooleanField(blank=True, null=True)),
                ('comissionsales', models.BooleanField(blank=True, null=True)),
                ('comissioncollection', models.BooleanField(blank=True, null=True)),
                ('comissionbudget', models.BooleanField(blank=True, null=True)),
                ('rolereceivablesid', models.IntegerField(blank=True, null=True)),
                ('rolecommercialid', models.IntegerField(blank=True, null=True)),
                ('validatecommercial', models.BooleanField(blank=True, null=True)),
                ('methodpromptpayment', models.IntegerField(blank=True, null=True)),
                ('discount', models.IntegerField(blank=True, null=True)),
                ('multicompanydistribution', models.BooleanField(blank=True, null=True)),
                ('pricetypedistributor', models.CharField(blank=True, max_length=1, null=True)),
                ('roleproductionid', models.IntegerField(blank=True, null=True)),
                ('taxpurchase', models.CharField(blank=True, max_length=1, null=True)),
                ('taxsales', models.CharField(blank=True, max_length=1, null=True)),
                ('typeproduction', models.CharField(blank=True, max_length=1, null=True)),
                ('presentation', models.BooleanField(blank=True, null=True)),
                ('dispatchcontrol', models.BooleanField(blank=True, null=True)),
                ('bicurrency', models.BooleanField(blank=True, null=True)),
                ('accounttaxexpense', models.BooleanField(blank=True, null=True)),
                ('typecontract', models.CharField(blank=True, max_length=1, null=True)),
                ('quotamoderator', models.BooleanField(blank=True, null=True)),
                ('bondrepurchase', models.BooleanField(blank=True, null=True)),
                ('costcenterinvoice', models.BooleanField(blank=True, null=True)),
                ('projectinvoice', models.BooleanField(blank=True, null=True)),
                ('validateexpirationinvoice', models.BooleanField(blank=True, null=True)),
                ('email', models.CharField(blank=True, max_length=100, null=True)),
                ('validateretentionorder', models.BooleanField(blank=True, null=True)),
                ('initialcash', models.CharField(blank=True, max_length=20, null=True)),
                ('changecash', models.CharField(blank=True, max_length=20, null=True)),
                ('type', models.CharField(blank=True, max_length=20, null=True)),
                ('initialdate', models.CharField(blank=True, max_length=20, null=True)),
                ('finaldate', models.CharField(blank=True, max_length=20, null=True)),
                ('documentrole', models.BooleanField(blank=True, null=True)),
                ('template', models.BooleanField(blank=True, null=True)),
                ('demo', models.BooleanField(blank=True, null=True)),
                ('created', models.DateField(blank=True, null=True)),
                ('createdby', models.IntegerField(blank=True, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('industryid', models.IntegerField(blank=True, null=True)),
                ('initial', models.DateField(blank=True, null=True)),
                ('smtpserver', models.CharField(blank=True, max_length=100, null=True)),
                ('port', models.CharField(blank=True, max_length=100, null=True)),
                ('emailoutput', models.CharField(blank=True, max_length=100, null=True)),
                ('passwordoutput', models.CharField(blank=True, max_length=100, null=True)),
                ('roundingcycle', models.CharField(blank=True, max_length=1, null=True)),
                ('health', models.CharField(blank=True, max_length=1, null=True)),
                ('activity', models.CharField(blank=True, max_length=4000, null=True)),
                ('image', models.BinaryField(blank=True, null=True)),
                ('timezoneid', models.IntegerField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('certicatessl', models.BooleanField(blank=True, null=True)),
                ('syncpublicationid', models.IntegerField(blank=True, null=True)),
                ('synclocationid', models.IntegerField(blank=True, null=True)),
                ('paymentmethod', models.CharField(blank=True, max_length=1, null=True)),
                ('paymentcode', models.CharField(blank=True, max_length=100, null=True)),
                ('payuapilogin', models.CharField(blank=True, max_length=100, null=True)),
                ('payuapikey', models.CharField(blank=True, max_length=300, null=True)),
                ('paymentaccount', models.CharField(blank=True, max_length=100, null=True)),
                ('psetargeturl', models.CharField(blank=True, max_length=500, null=True)),
                ('esignature', models.CharField(blank=True, max_length=100, null=True)),
                ('esignaturegoodthru', models.DateField(blank=True, null=True)),
                ('esignaturepassword', models.CharField(blank=True, max_length=100, null=True)),
                ('ebillproduction', models.BooleanField(blank=True, null=True)),
                ('ebill', models.BooleanField(blank=True, null=True)),
                ('sendebill', models.CharField(blank=True, max_length=1, null=True)),
                ('hoursbyday', models.IntegerField(blank=True, null=True)),
                ('ebilladjunct', models.BooleanField(blank=True, null=True)),
                ('companyidcentral', models.IntegerField(blank=True, null=True)),
                ('paymentmethodcredit', models.CharField(blank=True, max_length=1, null=True)),
                ('emailing', models.CharField(blank=True, max_length=1, null=True)),
                ('userimap', models.CharField(blank=True, max_length=20, null=True)),
                ('passwordimap', models.CharField(blank=True, max_length=20, null=True)),
                ('configimap', models.CharField(blank=True, max_length=1000, null=True)),
                ('testid', models.CharField(blank=True, max_length=100, null=True)),
                ('databaseid', models.IntegerField(blank=True, null=True)),
                ('bienabled', models.BooleanField(blank=True, null=True)),
                ('emailoutputfe', models.CharField(blank=True, max_length=100, null=True)),
                ('passwordoutputfe', models.CharField(blank=True, max_length=100, null=True)),
                ('supercodec', models.CharField(blank=True, max_length=6, null=True)),
                ('masterclientid', models.BigIntegerField(blank=True, null=True)),
                ('budgetcostcenter', models.BooleanField(blank=True, null=True)),
                ('budgetperiod', models.BooleanField(blank=True, null=True)),
            ],
            options={
                'db_table': 'company',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Company',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('company_id', models.IntegerField(verbose_name='Company Id')),
                ('name', models.CharField(max_length=100, verbose_name='Company Name')),
                ('tax_id', models.CharField(max_length=30, verbose_name='Tax Id')),
                ('address', models.CharField(max_length=100, verbose_name='Address')),
                ('phone', models.CharField(max_length=100, verbose_name='Phone Number')),
                ('city', models.CharField(max_length=100, verbose_name='City')),
                ('legal_representative', models.CharField(max_length=150, verbose_name='Legal Representative')),
                ('enabled', models.BooleanField(default=True, verbose_name='Enabled')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
